@@ -1,11 +1,8 @@
-from __future__ import unicode_literals
-
 import datetime
 
 from django.core import signing
 from django.db import models, transaction
 from django.utils import timezone
-from django.utils.crypto import get_random_string
 from django.utils.translation import gettext_lazy as _
 
 from .. import app_settings as allauth_app_settings
@@ -51,7 +48,8 @@ class EmailAddress(models.Model):
         self.primary = True
         self.save()
         user_email(self.user, self.email)
-        self.user.save()
+        if app_settings.USER_MODEL_EMAIL_FIELD:
+            self.user.save(update_fields=[app_settings.USER_MODEL_EMAIL_FIELD])
         return True
 
     def send_confirmation(self, request=None, signup=False):
@@ -68,7 +66,8 @@ class EmailAddress(models.Model):
         """
         with transaction.atomic():
             user_email(self.user, new_email)
-            self.user.save()
+            if app_settings.USER_MODEL_EMAIL_FIELD:
+                self.user.save(update_fields=[app_settings.USER_MODEL_EMAIL_FIELD])
             self.email = new_email
             self.verified = False
             self.save()
@@ -98,7 +97,7 @@ class EmailConfirmation(models.Model):
 
     @classmethod
     def create(cls, email_address):
-        key = get_random_string(64).lower()
+        key = get_adapter().generate_emailconfirmation_key(email_address.email)
         return cls._default_manager.create(email_address=email_address, key=key)
 
     def key_expired(self):
@@ -145,7 +144,7 @@ class EmailConfirmationHMAC:
         try:
             max_age = 60 * 60 * 24 * app_settings.EMAIL_CONFIRMATION_EXPIRE_DAYS
             pk = signing.loads(key, max_age=max_age, salt=app_settings.SALT)
-            ret = EmailConfirmationHMAC(EmailAddress.objects.get(pk=pk))
+            ret = EmailConfirmationHMAC(EmailAddress.objects.get(pk=pk, verified=False))
         except (
             signing.SignatureExpired,
             signing.BadSignature,
