@@ -12,19 +12,17 @@ from .provider import RedditProvider
 
 class RedditAdapter(OAuth2Adapter):
     provider_id = RedditProvider.id
-    access_token_url = 'https://www.reddit.com/api/v1/access_token'
-    authorize_url = 'https://www.reddit.com/api/v1/authorize'
-    profile_url = 'https://oauth.reddit.com/api/v1/me'
+    access_token_url = "https://www.reddit.com/api/v1/access_token"
+    authorize_url = "https://www.reddit.com/api/v1/authorize"
+    profile_url = "https://oauth.reddit.com/api/v1/me"
     basic_auth = True
 
     settings = app_settings.PROVIDERS.get(provider_id, {})
     # Allow custom User Agent to comply with reddit API limits
-    headers = {
-        'User-Agent': settings.get('USER_AGENT', 'django-allauth-header')}
+    headers = {"User-Agent": settings.get("USER_AGENT", "django-allauth-header")}
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {
-            "Authorization": "bearer " + token.token}
+        headers = {"Authorization": "bearer " + token.token}
         headers.update(self.headers)
         extra_data = requests.get(self.profile_url, headers=headers)
 
@@ -32,10 +30,7 @@ class RedditAdapter(OAuth2Adapter):
         if isinstance(extra_data, list):
             extra_data = extra_data[0]
 
-        return self.get_provider().sociallogin_from_response(
-            request,
-            extra_data.json()
-        )
+        return self.get_provider().sociallogin_from_response(request, extra_data.json())
 
 
 oauth2_login = OAuth2LoginView.adapter_view(RedditAdapter)
