@@ -3,7 +3,7 @@ from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
 class Scope(object):
-    ACCESS = 'read-only'
+    ACCESS = "read-only"
 
 
 class YNABAccount(ProviderAccount):
@@ -11,8 +11,8 @@ class YNABAccount(ProviderAccount):
 
 
 class YNABProvider(OAuth2Provider):
-    id = 'ynab'
-    name = 'YNAB'
+    id = "ynab"
+    name = "YNAB"
     account_class = YNABAccount
 
     def get_default_scope(self):
@@ -20,14 +20,13 @@ class YNABProvider(OAuth2Provider):
         return scope
 
     def get_auth_params(self, request, action):
-        ret = super(YNABProvider, self).get_auth_params(request,
-                                                        action)
+        ret = super(YNABProvider, self).get_auth_params(request, action)
         if action == AuthAction.REAUTHENTICATE:
-            ret['prompt'] = 'select_account consent'
+            ret["prompt"] = "select_account consent"
         return ret
 
     def extract_uid(self, data):
-        return str(data['data']['user']['id'])
+        return str(data["data"]["user"]["id"])
 
 
 provider_classes = [YNABProvider]
